@@ -29,7 +29,6 @@ Copyright 2014-2021 Anthony Larcher and Sylvain Meignier
 
 
 from .augmentation import AddNoise
-from .augmentation import AddReverb
 from .feed_forward import FForwardNetwork
 from .feed_forward import kaldi_to_hdf5
 from .xsets import XvectorMultiDataset, XvectorDataset, StatDataset
@@ -38,6 +37,16 @@ from .res_net import ResBlock, ResNet18
 from .rawnet import prepare_voxceleb1, Vox1Set, PreEmphasis
 from .sincnet import SincNet
 
+has_pyroom = True
+try:
+   import pyroomacoustics
+except ImportError:
+   has_pyroom = False
+
+if has_pyroom:
+    from .augmentation import AddReverb
+
+
 __author__ = "Anthony Larcher and Sylvain Meignier"
 __copyright__ = "Copyright 2014-2021 Anthony Larcher and Sylvain Meignier"
 __license__ = "LGPL"
