@@ -22,7 +22,7 @@
 # along with SIDEKIT.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-Copyright 2014-2020 Anthony Larcher
+Copyright 2014-2021 Anthony Larcher
 
 
 The authors would like to thank the BUT Speech@FIT group (http://speech.fit.vutbr.cz) and Lukas BURGET
@@ -45,7 +45,7 @@ from ..sidekit_wrappers import check_path_existance
 
 __license__ = "LGPL"
 __author__ = "Anthony Larcher"
-__copyright__ = "Copyright 2015-2020 Anthony Larcher"
+__copyright__ = "Copyright 2015-2021 Anthony Larcher"
 __maintainer__ = "Anthony Larcher"
 __email__ = "anthony.larcher@univ-lemans.fr"
 __status__ = "Production"
@@ -363,7 +363,7 @@ class FForwardNetwork():
 
             # Create the directory if it doesn't exist
             dir_name = os.path.dirname(output_file_structure.format(show))  # get the path
-            if not os.path.exists(dir_name) and (dir_name is not ''):
+            if not os.path.exists(dir_name) and not (dir_name == ''):
                 os.makedirs(dir_name)
 
             # Save in HDF5 format, labels are saved if they don't exist in the output file
