@@ -39,7 +39,7 @@ import soundfile
 import yaml
 
 from .augmentation import AddNoise
-from .augmentation import AddReverb
+#from .augmentation import AddReverb
 from ..bosaris.idmap import IdMap
 from ..frontend.vad import pre_emphasis
 from ..frontend.features import trfbank
@@ -469,15 +469,21 @@ class SideSet(Dataset):
                                                noise_root_path=self.transformation["noise_root_db"]))
 
                 if 'add_reverb' in t:
-                    self.add_reverb[:int(self.len * self.transformation["reverb_file_ratio"])] = 1
-                    numpy.random.shuffle(self.add_reverb)
+                    has_pyroom = True
+                    try:
+                        import pyroomacoustics
+                    except ImportError:
+                        has_pyroom = False
+                    if has_pyroom:
+                        self.add_reverb[:int(self.len * self.transformation["reverb_file_ratio"])] = 1
+                        numpy.random.shuffle(self.add_reverb)
 
-                    _transform.append(AddReverb(depth=self.transformation["reverb_depth"],
-                                                width=self.transformation["reverb_width"],
-                                                height=self.transformation["reverb_height"],
-                                                absorption=self.transformation["reverb_absorption"],
-                                                noise=None,
-                                                snr=self.transformation["reverb_snr"]))
+                        _transform.append(AddReverb(depth=self.transformation["reverb_depth"],
+                                                    width=self.transformation["reverb_width"],
+                                                    height=self.transformation["reverb_height"],
+                                                    absorption=self.transformation["reverb_absorption"],
+                                                    noise=None,
+                                                    snr=self.transformation["reverb_snr"]))
                 if 'MFCC' in t:
                     _transform.append(MFCC())
 
